/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */


/**************************************************************************
 *    Toolkit Window Structures
 **************************************************************************/

#define DATA_ELEMENTS         4


/**************************************************************************
 *    Toolkit Window Structures
 **************************************************************************/

typedef struct _AUX_EVENTREC {

	GLint        event;
	GLint        data[DATA_ELEMENTS];

}	AUX_EVENTREC;


typedef struct _AUX_COLORREC {

	GLint        index;
	GLfloat      r;
	GLfloat      g;
	GLfloat      b;

}	AUX_COLORREC;

/*
** ToolKit Window Types
*/

#define AUX_DIRECT	0
#define AUX_INDIRECT	4

/* 
** Window Masks
*/

#define AUX_WIND_IS_RGB(x)	(((x) & AUX_INDEX) == 0)
#define AUX_WIND_IS_INDEX(x)	(((x) & AUX_INDEX) != 0)
#define AUX_WIND_IS_SINGLE(x)	(((x) & AUX_DOUBLE) == 0)
#define AUX_WIND_IS_DOUBLE(x)	(((x) & AUX_DOUBLE) != 0)
#define AUX_WIND_IS_INDIRECT(x)	(((x) & AUX_INDIRECT) != 0)
#define AUX_WIND_IS_DIRECT(x)	(((x) & AUX_INDIRECT) == 0)
#define AUX_WIND_HAS_ACCUM(x)	(((x) & AUX_ACCUM) != 0)
#define AUX_WIND_HAS_ALPHA(x)	(((x) & AUX_ALPHA) != 0)
#define AUX_WIND_HAS_DEPTH(x)	(((x) & AUX_DEPTH) != 0)
#define AUX_WIND_HAS_STENCIL(x)	(((x) & AUX_STENCIL) != 0)

/*
** Color Macros
*/

enum {
    AUX_BLACK = 0,
    AUX_RED,
    AUX_GREEN,
    AUX_YELLOW,
    AUX_BLUE,
    AUX_MAGENTA,
    AUX_CYAN,
    AUX_WHITE
};

extern float auxRGBMap[8][3];

#define AUX_SETCOLOR(x, y) (AUX_WIND_IS_RGB((x)) ? \
		           glColor3fv(auxRGBMap[(y)]) : glIndexf((y)))

/*
** RGB Image Structure
*/

typedef struct _AUX_RGBImageRec {
    GLint sizeX, sizeY;
    unsigned char *data;
} AUX_RGBImageRec;

/**************************************************************************
 *    Toolkit Event Data Indices
 **************************************************************************/

#define AUX_WINDOWX           0
#define AUX_WINDOWY           1

#define AUX_MOUSEX            0
#define AUX_MOUSEY            1
#define AUX_MOUSESTATUS       3

#define AUX_KEY               0
#define AUX_KEYSTATUS         1


/**************************************************************************
 *    Toolkit 'Get' and 'Set' Function Defines
 **************************************************************************/

#define AUX_FD                1     /* return fd ( GLint ) */
#define AUX_COLORMAP          3     /* pass buf of r, g, and b, ( GLchar ) */
#define AUX_GREYSCALEMAP      4
#define AUX_FOGMAP            5     /* pas fog and color bits ( GLint ) */
#define AUX_ONECOLOR          6     /* pass index r, g, and b ( GLin */
